@@ -257,20 +257,18 @@ def image_decompress(fabba, strings):
 
 
 
-
-def load_images(shape=(250, 250)):
-    images = list()
-    folder = os.path.dirname(os.path.realpath(__file__))+'/samples/img'
-    figs = os.listdir(folder)
-    for filename in figs:
-        img = cv2.imread(os.path.join(folder,filename)) 
-        img = cv2.cvtColor(img,  cv2.COLOR_BGR2RGB) # transform to grayscale: cv2.COLOR_BGR2GRAY or RGB cv2.COLOR_BGR2RGB
-        img = cv2.resize(img, shape) # resize to 80x80
-        if img is not None:
-            images.append(img)
-    images = np.array(images)
-    # images = images.reshape(images.shape[0], images.shape[1]*images.shape[2])
-    return images
+# def load_images(shape=(250, 250)):
+#     images = list()
+#     folder = os.path.dirname(os.path.realpath(__file__))+'/samples/img'
+#     figs = os.listdir(folder)
+#     for filename in figs:
+#         img = cv2.imread(os.path.join(folder,filename)) 
+#         img = cv2.cvtColor(img,  cv2.COLOR_BGR2RGB) # transform to grayscale: cv2.COLOR_BGR2GRAY or RGB cv2.COLOR_BGR2RGB
+#         img = cv2.resize(img, shape) # resize to 80x80
+#         if img is not None:
+#             images.append(img)
+#     images = np.array(images)
+#     return images
 
 
 
